@@ -14,8 +14,15 @@ try:
 except ImportError:
     HAVE_DJANGO = False
 
+try:
+    from flask import current_app
 
-_DEFAULTS = {
+    HAVE_FLASK = True
+except ImportError:
+    HAVE_FLASK = False
+
+
+_DEFAULTS: dict = {
     'AWS_REGION': None,
     'AWS_ACCOUNT_ID': None,
     'AWS_ACCESS_KEY': None,
@@ -26,15 +33,12 @@ _DEFAULTS = {
     'AWS_SECRET_KEY': None,
     'AWS_SESSION_TOKEN': None,
     'GOOGLE_APPLICATION_CREDENTIALS': None,
-    'GOOGLE_PUBSUB_PROJECT_ID': None,
+    'GOOGLE_CLOUD_PROJECT': None,
     'GOOGLE_PUBSUB_READ_TIMEOUT_S': 5,
     'HEDWIG_CALLBACKS': {},
     'HEDWIG_CONSUMER_BACKEND': None,
     'HEDWIG_DATA_VALIDATOR_CLASS': 'hedwig.validator.MessageValidator',
     'HEDWIG_DEFAULT_HEADERS': 'hedwig.conf.default_headers_hook',
-    'HEDWIG_GOOGLE_MESSAGE_RETRY_STATE_BACKEND': None,
-    'HEDWIG_GOOGLE_MESSAGE_RETRY_STATE_REDIS_URL': None,
-    'HEDWIG_GOOGLE_MESSAGE_MAX_RETRIES': 3,
     'HEDWIG_MESSAGE_ROUTING': {},
     'HEDWIG_POST_DESERIALIZE_HOOK': 'hedwig.conf.noop_hook',
     'HEDWIG_PRE_PROCESS_HOOK': 'hedwig.conf.noop_hook',
@@ -74,10 +78,14 @@ def noop_hook(*args, **kwargs) -> None:
 
 class _LazySettings:
     """
-    A settings object, that allows settings to be accessed as properties.
+    A lazy object, that allows settings to be accessed as properties.
     For example:
+
+    .. code-block:: python
+
         from hedwig.conf import settings
         print(settings.AWS_REGION)
+
     Any setting with string import paths will be automatically resolved
     and return the class, rather than the string literal.
     """
@@ -88,8 +96,15 @@ class _LazySettings:
         self._import_dict_values = _IMPORT_DICT_VALUES
         self._user_settings: object = None
 
-    def ensure_configured(self):
-        if self._user_settings:
+    @property
+    def configured(self) -> bool:
+        """
+        Have Hedwig settings been configured?
+        """
+        return bool(self._user_settings)
+
+    def _ensure_configured(self):
+        if self.configured:
             return
 
         if os.environ.get("SETTINGS_MODULE"):
@@ -99,11 +114,19 @@ class _LazySettings:
             logging.info('Configuring Hedwig through django settings')
             # automatically import Django settings in Django projects
             self._user_settings = django_settings
+        elif HAVE_FLASK:
+            logging.info('Configuring Hedwig through flask settings')
+            # automatically import Flask settings in Flask projects
+            self._user_settings = current_app.config
         if not self._user_settings:
-            raise ImportError("No settings module found to import")
+            raise ImportError("Hedwig settings have not been configured")
 
     def configure_with_object(self, obj: object) -> None:
-        assert not self._user_settings, "settings have already been configured"
+        """
+        Set Hedwig config using a dataclass-like object that contains all settings as its attributes, or a dict that
+        contains settings as its keys.
+        """
+        assert not self._user_settings, "Hedwig settings have already been configured"
 
         logging.info('Configuring Hedwig through object')
         self._user_settings = deepcopy(obj)
@@ -131,22 +154,35 @@ class _LazySettings:
         except AttributeError as err:
             raise ImportError(f"Module '{module_path}' does not define a '{class_name}' attribute/class") from err
 
+    def _get_setting_from_object(self, attr: str):
+        if isinstance(self._user_settings, dict):
+            if attr in self._user_settings:
+                return self._user_settings[attr]
+            elif attr.lower() in self._user_settings:
+                return self._user_settings[attr.lower()]
+            raise RuntimeError
+        else:
+            try:
+                # Check if present in user settings
+                return getattr(self._user_settings, attr)
+            except AttributeError:
+                # try lowercase
+                try:
+                    return getattr(self._user_settings, attr.lower())
+                except AttributeError:
+                    raise RuntimeError
+
     def __getattr__(self, attr: str) -> typing.Any:
-        self.ensure_configured()
+        self._ensure_configured()
 
         if attr not in self._defaults:
             raise AttributeError("Invalid API setting: '%s'" % attr)
 
         try:
-            # Check if present in user settings
-            val = getattr(self._user_settings, attr)
-        except AttributeError:
-            # try lowercase
-            try:
-                val = getattr(self._user_settings, attr.lower())
-            except AttributeError:
-                # Fall back to defaults
-                val = self._defaults[attr]
+            val = self._get_setting_from_object(attr)
+        except RuntimeError:
+            # Fall back to defaults
+            val = self._defaults[attr]
 
         # Coerce import strings into classes
         if attr in self._import_strings:
@@ -160,6 +196,9 @@ class _LazySettings:
         return val
 
     def clear_cache(self) -> None:
+        """
+        Clear settings cache - useful for testing only
+        """
         for attr in self._defaults:
             try:
                 delattr(self, attr)
@@ -175,10 +214,16 @@ if HAVE_DJANGO:
 
 
 settings = _LazySettings()
+"""
+This object allows settings to be accessed as properties. Settings can be configured in one of three ways:
 
+#. Environment variable named ``SETTINGS_MODULE`` that points to a python module with settings as module attributes
 
-def configure_with_object(config: object) -> None:
-    """
-    Set Hedwig config using a dataclass-like object that contains all settings as it's attributes.
-    """
-    settings.configure_with_object(config)
+#. Django - if Django can be imported, Django settings will be used automatically
+
+#. Using an object or dict, by calling :meth:`hedwig.conf.settings.configure_with_object`
+
+Some setting values need to be string import paths will be automatically resolved and return the class.
+
+Once settings have been configured, they can't be changed.
+"""
